from proxmoxer import ProxmoxAPI
import time
import re
import sys
import paramiko

def test_proxmox_connection():
    try:
        nodes = proxmox.nodes.get()
        print("Connection successful. Nodes fetched:")
        for node in nodes:
            print(f"- {node['node']}")
    except Exception as e:
        print(f"Failed to connect: {e}")
        exit(1)

def get_all_containers_with_ips(node):
    containers = proxmox.nodes(node).lxc.get()
    container_info = []
    for ct in containers:
        vmid = ct.get("vmid")
        name = ct.get("name", f"VMID-{vmid}")
        config = proxmox.nodes(node).lxc(vmid).config.get()
        net0 = config.get("net0", "")
        ip_match = re.search(r"ip=([\d\.]+)", net0)
        ip_address = ip_match.group(1) if ip_match else "No IP Assigned"
        container_info.append((vmid, name, ip_address))
    return container_info



def main():

    host = sys.argv[1]
    user = sys.argv[2]
    token_name = sys.argv[3]
    token_value = sys.argv[4]
    verify_ssl = True if 'true' in sys.argv[5] else False

    global proxmox
    proxmox = ProxmoxAPI(
        host=host,
        user=user,
        token_name=token_name,
        token_value=token_value,
        verify_ssl=verify_ssl,
        timeout=30
    )

    test_proxmox_connection()

    node = "Debian-1201-bookworm-amd64-base"
    storage = "local"

    print("Fetching existing containers and their IPs...")
    containers = get_all_containers_with_ips(node)
    existing_ips = [ip for _, _, ip in containers if ip != "No IP Assigned"]
    print("Existing containers:")
    for vmid, name, ip in containers:
        print(f"VMID: {vmid}, Name: {name}, IP: {ip}")

if __name__ == "__main__":
    main()